"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.NamespaceRegistrationTransactionBuilder = void 0;
const GeneratorUtils_1 = require("./GeneratorUtils");
const NamespaceRegistrationTransactionBodyBuilder_1 = require("./NamespaceRegistrationTransactionBodyBuilder");
const NamespaceRegistrationTypeDto_1 = require("./NamespaceRegistrationTypeDto");
const TransactionBuilder_1 = require("./TransactionBuilder");
class NamespaceRegistrationTransactionBuilder extends TransactionBuilder_1.TransactionBuilder {
    constructor({ signature, signerPublicKey, version, network, type, fee, deadline, duration, parentId, id, registrationType, name, }) {
        super({ signature, signerPublicKey, version, network, type, fee, deadline });
        this.namespaceRegistrationTransactionBody = new NamespaceRegistrationTransactionBodyBuilder_1.NamespaceRegistrationTransactionBodyBuilder({
            duration,
            parentId,
            id,
            registrationType,
            name,
        });
    }
    static loadFromBinary(payload) {
        const byteArray = Array.from(payload);
        const superObject = TransactionBuilder_1.TransactionBuilder.loadFromBinary(payload);
        byteArray.splice(0, superObject.size);
        const namespaceRegistrationTransactionBody = NamespaceRegistrationTransactionBodyBuilder_1.NamespaceRegistrationTransactionBodyBuilder.loadFromBinary(Uint8Array.from(byteArray));
        byteArray.splice(0, namespaceRegistrationTransactionBody.size);
        return new NamespaceRegistrationTransactionBuilder({
            signature: superObject.signature,
            signerPublicKey: superObject.signerPublicKey,
            version: superObject.version,
            network: superObject.network,
            type: superObject.type,
            fee: superObject.fee,
            deadline: superObject.deadline,
            duration: namespaceRegistrationTransactionBody.duration,
            parentId: namespaceRegistrationTransactionBody.parentId,
            id: namespaceRegistrationTransactionBody.id,
            registrationType: namespaceRegistrationTransactionBody.registrationType,
            name: namespaceRegistrationTransactionBody.name,
        });
    }
    static createNamespaceRegistrationTransactionBuilderChild(signature, signerPublicKey, version, network, type, fee, deadline, parentId, id, name) {
        const registrationType = NamespaceRegistrationTypeDto_1.NamespaceRegistrationTypeDto.CHILD;
        return new NamespaceRegistrationTransactionBuilder({
            signature: signature,
            signerPublicKey: signerPublicKey,
            version: version,
            network: network,
            type: type,
            fee: fee,
            deadline: deadline,
            parentId: parentId,
            id: id,
            registrationType: registrationType,
            name: name,
        });
    }
    static createNamespaceRegistrationTransactionBuilderRoot(signature, signerPublicKey, version, network, type, fee, deadline, duration, id, name) {
        const registrationType = NamespaceRegistrationTypeDto_1.NamespaceRegistrationTypeDto.ROOT;
        return new NamespaceRegistrationTransactionBuilder({
            signature: signature,
            signerPublicKey: signerPublicKey,
            version: version,
            network: network,
            type: type,
            fee: fee,
            deadline: deadline,
            duration: duration,
            id: id,
            registrationType: registrationType,
            name: name,
        });
    }
    get duration() {
        return this.namespaceRegistrationTransactionBody.duration;
    }
    get parentId() {
        return this.namespaceRegistrationTransactionBody.parentId;
    }
    get id() {
        return this.namespaceRegistrationTransactionBody.id;
    }
    get registrationType() {
        return this.namespaceRegistrationTransactionBody.registrationType;
    }
    get name() {
        return this.namespaceRegistrationTransactionBody.name;
    }
    get size() {
        let size = super.size;
        size += this.namespaceRegistrationTransactionBody.size;
        return size;
    }
    get body() {
        return this.namespaceRegistrationTransactionBody;
    }
    serialize() {
        let newArray = Uint8Array.from([]);
        const superBytes = super.serialize();
        newArray = GeneratorUtils_1.GeneratorUtils.concatTypedArrays(newArray, superBytes);
        const namespaceRegistrationTransactionBodyBytes = this.namespaceRegistrationTransactionBody.serialize();
        newArray = GeneratorUtils_1.GeneratorUtils.concatTypedArrays(newArray, namespaceRegistrationTransactionBodyBytes);
        return newArray;
    }
}
exports.NamespaceRegistrationTransactionBuilder = NamespaceRegistrationTransactionBuilder;
//# sourceMappingURL=NamespaceRegistrationTransactionBuilder.js.map